[gnome-software/1364-implement-other-apps-by-author-section-in-app-details-page] GsAppQuery::other-apps fixups



commit b0d3893f9499abc81d866c87a4cb037707e71639
Author: Philip Withnall <philip tecnocode co uk>
Date:   Mon May 16 11:31:20 2022 +0000

    GsAppQuery::other-apps fixups

 lib/gs-app-query.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)
---
diff --git a/lib/gs-app-query.c b/lib/gs-app-query.c
index 84952282b..ed8ad9743 100644
--- a/lib/gs-app-query.c
+++ b/lib/gs-app-query.c
@@ -447,7 +447,7 @@ gs_app_query_class_init (GsAppQueryClass *klass)
                                    G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
        /**
-        * GsAppQuery:other_apps: (nullable)
+        * GsAppQuery:other-apps: (nullable)
         *
         * A list of developers to search the apps for.
         *
@@ -460,7 +460,7 @@ gs_app_query_class_init (GsAppQueryClass *klass)
         */
        props[PROP_OTHER_APPS] =
                g_param_spec_boxed ("other-apps", "Other Apps",
-                                   "A list of developers, whom provide the apps.",
+                                   "A list of developers who provide the apps.",
                                    G_TYPE_STRV,
                                    G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY |
                                    G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
@@ -641,7 +641,7 @@ gs_app_query_get_released_since (GsAppQuery *self)
  *
  * Get the value of #GsAppQuery:other-apps.
  *
  * Returns: (nullable): a list of developers, whom provide the apps,
  *   or %NULL to not filter by it
  * Since: 43
  */
@@ -641,7 +641,7 @@ gs_app_query_get_released_since (GsAppQuery *self)
  * Get the value of #GsAppQuery:other-apps.
  *
- * Returns: (nullable): a list of developers, whom provide the apps,
+ * Returns: (nullable): a list of developers who provide the apps,
  *   or %NULL to not filter by it
  * Since: 43


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]